## App features

- Option to flatten sources when adding to tarball (e.g., for [arXiv.org](https://arxiv.org/) submissions).
- Handling very large working repositories: `git checkout` may be too slow in these cases.
- Handling git projects with submodules?

## Documentation and miscellaneous

- Add type hints for functions.
- Improved doc strings.
- Add man/info file.
- Add CONTRIBUTING.md to invite contributions?
- Snazzier README, including:
  * Visual proof of tartex in action (`asciinema rec`)
  * Slogan, badge, etc.
